MessageCreateTemplate

Struct MessageCreateTemplate 

pub struct MessageCreateTemplate {
Show 13 fields pub max_tokens: Option<u32>, pub messages: Option<Vec<MessageParam>>, pub model: Option<Model>, pub metadata: Option<Metadata>, pub stop_sequences: Option<Vec<String>>, pub system: Option<SystemPrompt>, pub temperature: Option<f32>, pub thinking: Option<ThinkingConfig>, pub tool_choice: Option<ToolChoice>, pub tools: Option<Vec<ToolUnionParam>>, pub top_k: Option<u32>, pub top_p: Option<f32>, pub stream: Option<bool>,
}
A template for creating message parameters.

Every field in this template is optional, allowing you to specify only the fields you want to override. Use the apply method to apply the template to a MessageCreateParams instance.

Example

let template = MessageCreateTemplate::new()
    .with_max_tokens(2048)
    .with_temperature(0.7)
    .unwrap();

let params = MessageCreateParams::simple("Hello", KnownModel::ClaudeSonnet46);
let params = template.apply(params);

assert_eq!(params.max_tokens, 2048);
assert_eq!(params.temperature, Some(0.7));

Fields

max_tokens: Option<u32>

The maximum number of tokens to generate before stopping.

messages: Option<Vec<MessageParam>>

Input messages.

model: Option<Model>

The model that will complete your prompt.

metadata: Option<Metadata>

An object describing metadata about the request.

stop_sequences: Option<Vec<String>>

Custom text sequences that will cause the model to stop generating.

system: Option<SystemPrompt>

System prompt.

temperature: Option<f32>

Amount of randomness injected into the response.

thinking: Option<ThinkingConfig>

Configuration for enabling Claude’s extended thinking.

tool_choice: Option<ToolChoice>

How the model should use the provided tools.

tools: Option<Vec<ToolUnionParam>>

Definitions of tools that the model may use.

top_k: Option<u32>

Only sample from the top K options for each subsequent token.

top_p: Option<f32>

Use nucleus sampling.

stream: Option<bool>

Whether to incrementally stream the response using server-sent events.

Implementations

Source

impl MessageCreateTemplate

pub fn new() -> Self

Create a new empty template.

pub fn with_max_tokens(self, max_tokens: u32) -> Self

Set the max_tokens field.

pub fn with_messages(self, messages: Vec<MessageParam>) -> Self

Set the messages field.

pub fn with_model(self, model: impl Into<Model>) -> Self

Set the model field.

pub fn with_metadata(self, metadata: Metadata) -> Self

Set the metadata field.

pub fn with_stop_sequences(self, stop_sequences: Vec<String>) -> Self

Set the stop_sequences field.

pub fn with_system(self, system: impl Into<SystemPrompt>) -> Self

Set the system prompt field.

pub fn with_temperature(self, temperature: f32) -> Result<Self, Error>

Set the temperature field.

pub fn with_thinking(self, thinking: ThinkingConfig) -> Self

Set the thinking configuration field.

pub fn with_tool_choice(self, tool_choice: ToolChoice) -> Self

Set the tool_choice field.

pub fn with_tools(self, tools: Vec<ToolUnionParam>) -> Self

Set the tools field.

pub fn with_top_k(self, top_k: u32) -> Self

Set the top_k field.

pub fn with_top_p(self, top_p: f32) -> Result<Self, Error>

Set the top_p field.

pub fn with_stream(self, stream: bool) -> Self

Set the stream field.

pub fn merge(self, other: MessageCreateTemplate) -> Self

Merge another template into this one, overriding any fields set in other.

pub fn apply(self, params: MessageCreateParams) -> MessageCreateParams

Apply this template to the given MessageCreateParams.

Fields that are Some in the template will override the corresponding fields in the params. Fields that are None in the template will leave the params unchanged.